package anywheresoftware.b4a.objects;

import android.content.Intent;
import anywheresoftware.b4a.BA;
import anywheresoftware.b4a.IOnActivityResult;
import anywheresoftware.b4a.BA.ActivityObject;
import anywheresoftware.b4a.BA.DependsOn;
import anywheresoftware.b4a.BA.Events;
import anywheresoftware.b4a.BA.Permissions;
import anywheresoftware.b4a.BA.ShortName;
import anywheresoftware.b4a.BA.Version;

import com.google.android.youtube.player.YouTubeApiServiceUtil;
import com.google.android.youtube.player.YouTubeStandalonePlayer;

/**
 * This object allows you to play YouTube videos in your application.
 *See the <link>tutorial|http://www.basic4ppc.com/forum/showthread.php?p=143693</link> for more information.
 */
@ShortName("YouTubeStandalonePlayer")
@Version(1.0f)
@DependsOn(values={"YouTubeAndroidPlayerApi"})
@ActivityObject
@Permissions(values={"android.permission.INTERNET"})
@Events(values={"Result (Message As String)"})
public class YouTubeStandalonePlayerWrapper {
	private IOnActivityResult ion;
	private String eventName;
	/**
	 * Initializes the object and sets the sub that will handle the events.
	 */
	public void Initialize(String EventName) {
		this.eventName = EventName.toLowerCase(BA.cul);
	}
	/**
	 * Tests whether the YouTube player service is supported.
	 *Returns SUCCESS or an error message..
	 */
	public String CheckPlayerSupported() {
		return YouTubeApiServiceUtil.isYouTubeApiServiceAvailable(BA.applicationContext).toString();
	}
	/**
	 * Plays the videos in the playlist.
	 *DeveloperKey - The developer key from Google APIs console.
	 *PlaylistId - YouTube playlist id (the list value in the URL).
	 *StartIndex - The index of the video to be played first. The first index is 0.
	 *TimeMillis - The time in milliseconds where playback should start in the first video.
	 *AutoPlay - Whether the playback should start automatically.
	 *LightboxMode - If true then the video is played in a dialog over the current activity, 
	 * otherwise the video is played in its own activity (forced to landscape orientation).
	 */
	public void StartPlaylist(final BA ba, String DeveloperKey, String PlaylistId, int StartIndex, int TimeMillis, boolean AutoPlay, boolean LightboxMode) {
		startIntent(ba, YouTubeStandalonePlayer.createPlaylistIntent(ba.activity, DeveloperKey, PlaylistId, StartIndex, TimeMillis, AutoPlay, LightboxMode));
	}
	/**
	 * Plays the video.
	 *DeveloperKey - The developer key from Google APIs console.
	 *VideoId - YouTube video id.
	 *TimeMillis - The time in milliseconds where playback should star.
	 *AutoPlay - Whether the playback should start automatically.
	 *LightboxMode - If true then the video is played in a dialog over the current activity, 
	 * otherwise the video is played in its own activity (forced to landscape orientation).
	 */
	public void StartVideo(final BA ba, String DeveloperKey, String VideoId, int TimeMillis, boolean AutoPlay, boolean LightboxMode) {
		startIntent(ba, YouTubeStandalonePlayer.createVideoIntent(ba.activity, DeveloperKey, VideoId, TimeMillis, AutoPlay, LightboxMode));
	}
	private void startIntent(final BA ba, Intent i) {
		ion = new IOnActivityResult() {

	        @Override
	        public void ResultArrived(int resultCode, Intent intent) {
	            ba.raiseEvent(this, eventName + "_result", "" + YouTubeStandalonePlayer.getReturnedInitializationResult(intent).toString());
	        }
	    };
	    ba.startActivityForResult(ion, i);
	}
}
